primesieve: CLI program and C/C++ library for generating primes 
===============================================================

Description
-----------

A CLI program and C/C++ library for quickly generating prime numbers.
https://github.com/kimwalisch/primesieve

A dependency of the standard spkg primecount.

License
-------

BSD-2-clause

Upstream Contact
----------------

- https://github.com/kimwalisch/primesieve
